@@ -18,51 +18,31 @@ class QStyleOptionViewItem;
 class KWidgetItemDelegate;
 class KWidgetItemDelegatePoolPrivate;
 
-/**
-  * @internal
-  */
 class KWidgetItemDelegatePool
 {
 public:
     enum UpdateWidgetsEnum {
         UpdateWidgets = 0,
-        NotUpdateWidgets
+        NotUpdateWidgets,
     };
 
-    /**
-      * Creates a new ItemDelegatePool.
-      *
-      * @param delegate the ItemDelegate for this pool.
-      */
-
     KWidgetItemDelegatePool(KWidgetItemDelegate *delegate);
 
-    /**
-      * Destroys an ItemDelegatePool.
-      */
     ~KWidgetItemDelegatePool();
 
     KWidgetItemDelegatePool(const KWidgetItemDelegatePool &) = delete;
     KWidgetItemDelegatePool &operator=(const KWidgetItemDelegatePool &) = delete;
 
-    /**
-      * @brief Returns the widget associated to @p index and @p widget
-      * @param index The index to search into.
-      * @param option a QStyleOptionViewItem.
-      * @return A QList of the pointers to the widgets found.
-      * @internal
-      */
-    QList<QWidget *> findWidgets(const QPersistentModelIndex &index, const QStyleOptionViewItem &option,
-                                 UpdateWidgetsEnum updateWidgets = UpdateWidgets) const;
+    /*
+     * Returns the widget associated to index and widget
+     * index The index to search into.
+     * option a QStyleOptionViewItem.
+     * Returns a QList of the pointers to the widgets found.
+     */
+    QList<QWidget *> findWidgets(const QPersistentModelIndex &index, const QStyleOptionViewItem &option, UpdateWidgetsEnum updateWidgets = UpdateWidgets) const;
 
-    /**
-      * @internal
-      */
     QList<QWidget *> invalidIndexesWidgets() const;
 
-    /**
-      * @internal
-      */
     void fullClear();
 
 private:
@@ -73,20 +53,15 @@ private:
 
 class KWidgetItemDelegateEventListener;
 
-/**
-  * @internal
-  */
 class KWidgetItemDelegatePoolPrivate
 {
 public:
-
     KWidgetItemDelegatePoolPrivate(KWidgetItemDelegate *d);
 
     KWidgetItemDelegate *delegate;
     KWidgetItemDelegateEventListener *eventListener;
 
-    QList<QList<QWidget *> > allocatedWidgets;
-    QHash<QPersistentModelIndex, QList<QWidget *> > usedWidgets;
+    QHash<QPersistentModelIndex, QList<QWidget *>> usedWidgets;
     QHash<QWidget *, QPersistentModelIndex> widgetInIndex;
 
     bool clearing = false;
